==> CLDAQ-1.8.2.tar.gz: CLDAQ/source/event/TEvent.cc <==
// =====================================================================
//  $Id: TEvent.cc,v 1.2 2003/07/30 16:18:09 goiwai Exp $
//  $Name: CLDAQ-1-08-02 $
//
//  $Log: TEvent.cc,v $
//  Revision 1.2  2003/07/30 16:18:09  goiwai
//  ե˥ߥåȥĤ뤳Ȥˤޤ.
//
// =====================================================================
#include "TEvent.hh"

TEvent::TEvent( Tint eventID )
  : theEventID( eventID ), theDataRecord()
{;}

TEvent::TEvent( const TDataRecord& eventData )
  : theEventID( 0 ), theDataRecord( eventData )
{;}

TEvent::TEvent( Tint eventID, const TDataRecord& eventData )
  : theEventID( eventID ), theDataRecord( eventData )
{;}

TEvent::TEvent( const TEvent& right )
  : theEventID( right.theEventID ), 
    theDataRecord( right.theDataRecord )
{;}

TEvent::~TEvent()
{;}

const TEvent& TEvent::operator=( const TEvent& right )
{
  theEventID = right.theEventID;
  theDataRecord = right.theDataRecord;
  return( *this );
}

Tbool TEvent::operator==( const TEvent& right ) const
{
  if ( theEventID == right.theEventID && theDataRecord == right.theDataRecord ) {
    return( Ttrue );
  } else {
    return( Tfalse );
  }
}

Tbool TEvent::operator!=( const TEvent& right ) const
{
  if ( theEventID != right.theEventID || theDataRecord != right.theDataRecord ) {
    return( Ttrue );
  } else {
    return( Tfalse );
  }
}

Tvoid TEvent::Clear()
{
  theDataRecord.Clear();
  theEventID = 0;
  return;
}

Tstring TEvent::GetStringEventID( Tint digits ) const
{
  return( itostr( theEventID, digits ) );
}

==> CLDAQ-1.10.0.tar.gz: CLDAQ/source/event/TEvent.cc <==
// =====================================================================
//  $Id: TEvent.cc,v 1.3 2003/10/06 16:56:02 goiwai Exp $
//  $Name: CLDAQ-1-10-00 $
//  $Log: TEvent.cc,v $
//  Revision 1.3  2003/10/06 16:56:02  goiwai
//  *** empty log message ***
//
//  Revision 1.2  2003/07/30 16:18:09  goiwai
//  ե˥ߥåȥĤ뤳Ȥˤޤ.
//
// =====================================================================
#include "TEvent.hh"

TEvent::TEvent( Tint eventID )
  : theEventID( eventID ), theDataRecord()
{;}

TEvent::TEvent( const TDataRecord& eventData )
  : theEventID( 0 ), theDataRecord( eventData )
{;}

TEvent::TEvent( Tint eventID, const TDataRecord& eventData )
  : theEventID( eventID ), theDataRecord( eventData )
{;}

TEvent::TEvent( const TEvent& right )
  : theEventID( right.theEventID ), 
    theDataRecord( right.theDataRecord )
{;}

TEvent::~TEvent()
{;}

const TEvent& TEvent::operator=( const TEvent& right )
{
  theEventID = right.theEventID;
  theDataRecord = right.theDataRecord;
  return *this;
}

Tbool TEvent::operator==( const TEvent& right ) const
{
  if ( theEventID == right.theEventID && theDataRecord == right.theDataRecord ) {
    return Ttrue;
  } else {
    return Tfalse;
  }
}

Tbool TEvent::operator!=( const TEvent& right ) const
{
  if ( theEventID != right.theEventID || theDataRecord != right.theDataRecord ) {
    return Ttrue;
  } else {
    return Tfalse;
  }
}

Tvoid TEvent::Clear()
{
  theDataRecord.Clear();
  theEventID = 0;
  return;
}

Tstring TEvent::GetStringEventID( Tint digits ) const
{
  return itostr( theEventID, digits );
}
